==> MediaWikiLanguageExtensionBundle-2012.12.tar.bz2: extensions/UniversalLanguageSelector/UniversalLanguageSelector.i18n.php <==
<?php
/**
 * Internationalisation file for Universal Language Selector.
 *
 * Copyright (C) 2012 Alolita Sharma, Amir Aharoni, Arun Ganesh, Brandon Harris,
 * Niklas Laxström, Pau Giner, Santhosh Thottingal, Siebrand Mazeland and other
 * contributors. See CREDITS for a list.
 *
 * UniversalLanguageSelector is dual licensed GPLv2 or later and MIT. You don't
 * have to do anything special to choose one license or the other and you don't
 * have to notify anyone which license you are using. You are free to use
 * UniversalLanguageSelector in commercial projects as long as the copyright
 * header is left intact. See files GPL-LICENSE and MIT-LICENSE for details.
 *
 * @file
 * @ingroup Extensions
 * @licence GNU General Public Licence 2.0 or later
 * @licence MIT License
 */

$messages = array();

/**
 * English
 * @author santhosh
 */
$messages['en'] = array(
	'UniversalLanguageSelector' => 'Universal Language Selector',
	'uls-desc' => 'Gives the user several ways to select a language and to adjust language settings',
	'uls-select-content-language' => 'Select language',
);

/** Message documentation (Message documentation)
 */
$messages['qqq'] = array(
	'UniversalLanguageSelector' => 'Extension name',
	'uls-desc' => 'Extension description',
	'uls-select-content-language' => 'Main heading in the language selector popup.',
);

/** Assamese (অসমীয়া)
 * @author Bishnu Saikia
 */
$messages['as'] = array(
	'UniversalLanguageSelector' => 'গোলকীয় ভাষা নিৰ্বাচক',
	'uls-select-content-language' => 'ভাষা নির্বাচন:',
);

/** Asturian (asturianu)
 * @author Xuacu
 */
$messages['ast'] = array(
	'UniversalLanguageSelector' => 'Selector universal de llingua',
	'uls-desc' => 'Ufre al usuariu delles maneres pa seleicionar una llingua y axustar la configuración de llingua',
	'uls-select-content-language' => 'Escueyi llingua',
);

/** Belarusian (Taraškievica orthography) (беларуская (тарашкевіца)‎)
 * @author Wizardist
 */
$messages['be-tarask'] = array(
	'UniversalLanguageSelector' => 'Унівэрсальны пераключальнік моваў',
	'uls-desc' => 'Дае карыстальніку некалькі спосабаў выбраць мову і зьмяніць моўныя налады',
	'uls-select-content-language' => 'Выбар мовы',
);

/** Breton (brezhoneg)
 * @author Y-M D
 */
$messages['br'] = array(
	'uls-select-content-language' => 'Dibab ar yezh',
);

/** Czech (česky)
 * @author Mormegil
 */
$messages['cs'] = array(
	'UniversalLanguageSelector' => 'Univerzální výběr jazyka',
	'uls-desc' => 'Nabízí uživateli několik způsobů volby jazyka a úpravy jazykových nastavení',
	'uls-select-content-language' => 'Vyberte jazyk',
);

/** Danish (dansk)
 * @author Peter Alberti
 */
$messages['da'] = array(
	'uls-select-content-language' => 'Vælg sprog',
);

/** German (Deutsch)
 * @author Kghbln
 * @author MF-Warburg
 * @author Metalhead64
 */
$messages['de'] = array(
	'UniversalLanguageSelector' => 'Universelle Sprachauswahl',
	'uls-desc' => 'Ermöglicht verschiedene Wege, eine Sprache auszuwählen und Spracheinstellungen anzupassen',
	'uls-select-content-language' => 'Sprache auswählen',
);

/** Lower Sorbian (dolnoserbski)
 * @author Michawiki
 */
$messages['dsb'] = array(
	'UniversalLanguageSelector' => 'Uniwersalny wuběrk rěcow',
	'uls-desc' => 'Dawa wužywarjeju wšake metody, aby rěc wubrał a rěcne nastajenja pśiměrił',
	'uls-select-content-language' => 'Rěc wubraś',
);

/** Spanish (español)
 * @author Armando-Martin
 */
$messages['es'] = array(
	'UniversalLanguageSelector' => 'Selector universal de idiomas',
	'uls-desc' => 'Ofrece al usuario varias formas para seleccionar un idioma y ajustar su configuración',
	'uls-select-content-language' => 'Seleccionar idioma',
);

/** Estonian (eesti)
 * @author Pikne
 */
$messages['et'] = array(
	'UniversalLanguageSelector' => 'Universaalne keelevalija',
	'uls-desc' => 'Võimaldab kasutajal mitmel viisil keelt valida ja keelesätteid kohandada.',
	'uls-select-content-language' => 'Keele valimine',
);

/** Basque (euskara)
 * @author An13sa
 */
$messages['eu'] = array(
	'uls-select-content-language' => 'Hizkuntza aukeratu',
);

/** Finnish (suomi)
 * @author Nike
 */
$messages['fi'] = array(
	'UniversalLanguageSelector' => 'Suuri kielenvalitsin',
	'uls-desc' => 'Tarjoaa useita tapoja valita kieli ja asettaa kieliasetukset',
	'uls-select-content-language' => 'Valitse kieli',
);

/** French (français)
 * @author Tititou36
 * @author Wyz
 */
$messages['fr'] = array(
	'UniversalLanguageSelector' => 'Sélecteur de Langue Universel',
	'uls-desc' => "Donne à l'utilisateur plusieurs manières de sélectionner une langue et d'ajuster les paramètres de langue",
	'uls-select-content-language' => 'Sélectionner la langue',
);

/** Galician (galego)
 * @author Toliño
 */
$messages['gl'] = array(
	'UniversalLanguageSelector' => 'Selector universal de linguas',
	'uls-desc' => 'Dá ao usuario varios xeitos de seleccionar unha lingua e de axustar as preferencias da mesma',
	'uls-select-content-language' => 'Seleccionar a lingua',
);

/** Hebrew (עברית)
 * @author Amire80
 */
$messages['he'] = array(
	'UniversalLanguageSelector' => 'בורר השפות העולמי',
	'uls-desc' => 'נותן למשתמשים מספר דרכים לבחור שפה ולכוונן את הגדרות השפה',
	'uls-select-content-language' => 'בחירת שפה',
);

/** Upper Sorbian (hornjoserbsce)
 * @author Michawiki
 */
$messages['hsb'] = array(
	'UniversalLanguageSelector' => 'Uniwersalny wuběr rěčow',
	'uls-desc' => 'Dawa wužiwarjej wšelake metody, zo by rěč wubrał a rěčne nastajenja přiměrił',
	'uls-select-content-language' => 'Rěč wubrać',
);

/** Italian (italiano)
 * @author Darth Kule
 */
$messages['it'] = array(
	'UniversalLanguageSelector' => 'Selettore universale della lingua',
	'uls-desc' => 'Fornisce agli utenti diversi modi di selezionare una lingua e sistemare le impostazioni della lingua',
	'uls-select-content-language' => 'Seleziona lingua',
);

/** Japanese (日本語)
 * @author Shirayuki
 */
$messages['ja'] = array(
	'UniversalLanguageSelector' => 'ユニバーサル言語選択',
	'uls-desc' => '言語を選択するため/言語設定を調整するための、いくつかの方法を利用者に提供する',
	'uls-select-content-language' => '言語を選択',
);

/** Georgian (ქართული)
 * @author გიორგიმელა
 */
$messages['ka'] = array(
	'UniversalLanguageSelector' => 'ენების უნივერსალური გადამრთველი',
	'uls-desc' => 'აძლევს მომხმარებელს ენის არჩევისა და კონფიგურაციის საშუალებას',
	'uls-select-content-language' => 'ენის არჩევა',
);

/** Korean (한국어)
 * @author 아라
 */
$messages['ko'] = array(
	'UniversalLanguageSelector' => '범용 언어 선택기',
	'uls-desc' => '사용자에게 언어를 선택하고 언어 설정을 바꾸는 몇 가지 방법을 제공',
	'uls-select-content-language' => '언어 선택',
);

/** Colognian (Ripoarisch)
 * @author Purodha
 */
$messages['ksh'] = array(
	'UniversalLanguageSelector' => 'Alljemein Schproochewahl',
	'uls-desc' => 'Jit dä Metmaachere ongerscheidlejje Müjjeleschkeite, en Schprooch ußzewähle un Enschtällonge für Schprooche ze maache.',
	'uls-select-content-language' => 'En Schprooch ußwähle',
);

/** Luxembourgish (Lëtzebuergesch)
 * @author Robby
 */
$messages['lb'] = array(
	'UniversalLanguageSelector' => 'Universell Auswiel vun der Sprooch',
	'uls-desc' => "Gëtt dem Benotzer verschidde Méiglechkeete fir eng Sprooch erauszesichen an d'Parameter vun der Sprooch festzeleeën",
	'uls-select-content-language' => 'Sprooch eraussichen',
);

/** Macedonian (македонски)
 * @author Bjankuloski06
 */
$messages['mk'] = array(
	'UniversalLanguageSelector' => 'Универзален избирач на јазици',
	'uls-desc' => 'Му дава на корисникот неколку начини за избор на јазик и прилагодување на јазичните поставки',
	'uls-select-content-language' => 'Одберете јазик',
);

/** Malayalam (മലയാളം)
 * @author Santhosh.thottingal
 */
$messages['ml'] = array(
	'UniversalLanguageSelector' => 'ആഗോള ഭാഷാസഹായി',
	'uls-desc' => 'ഭാഷ തിരഞ്ഞെടുക്കുന്നതിനും സജ്ജീകരിക്കുന്നതിനുമുള്ള സംവിധാനം',
	'uls-select-content-language' => 'ഭാഷ തിരഞ്ഞെടുക്കുക',
);

/** Malay (Bahasa Melayu)
 * @author Anakmalaysia
 */
$messages['ms'] = array(
	'UniversalLanguageSelector' => 'Pemilih Bahasa Sejagat',
	'uls-desc' => 'Membolehkan pengguna memilih bahasa dan mengubah tetapan bahasa dengan pelbagai cara',
	'uls-select-content-language' => 'Pilih bahasa',
);

/** Dutch (Nederlands)
 * @author Siebrand
 */
$messages['nl'] = array(
	'UniversalLanguageSelector' => 'Universele taalkiezer',
	'uls-desc' => 'Biedt gebruikers verschillende mogelijkheden om een taal te kiezen en bijbehorende instellingen aan te passen',
	'uls-select-content-language' => 'Taal selecteren',
);

/** Polish (polski)
 * @author BeginaFelicysym
 */
$messages['pl'] = array(
	'UniversalLanguageSelector' => 'Uniwersalny Selektor Języka',
	'uls-desc' => 'Daje użytkownikowi kilka sposobów, aby wybrać język i dostosować ustawienia języka',
	'uls-select-content-language' => 'Wybierz język',
);

/** Brazilian Portuguese (português do Brasil)
 * @author Jaideraf
 */
$messages['pt-br'] = array(
	'UniversalLanguageSelector' => 'Seletor universal de idiomas',
	'uls-desc' => 'Oferece ao usuário várias maneiras para selecionar um idioma e ajustar as configurações de idioma',
	'uls-select-content-language' => 'Selecionar idioma',
);

/** Romanian (română)
 * @author Minisarm
 */
$messages['ro'] = array(
	'UniversalLanguageSelector' => 'Selector universal de limbi',
	'uls-desc' => 'Oferă utilizatorului mai multe modalități de a selecta o limbă și de a modifica setările de limbă',
	'uls-select-content-language' => 'Selectare limbă',
);

/** Russian (русский)
 * @author Amire80
 */
$messages['ru'] = array(
	'UniversalLanguageSelector' => 'Универсальный переключатель языков',
	'uls-desc' => 'Даёт пользователю несколько способов выбрать язык и произвести установки языка',
	'uls-select-content-language' => 'Выбор языка',
);

/** Tamil (தமிழ்)
 * @author Logicwiki
 */
$messages['ta'] = array(
	'UniversalLanguageSelector' => 'உலகளாவிய மொழி தேர்வுக் கருவி',
	'uls-desc' => 'பயனருக்கு மொழியை மாற்றவும் மொழி அமைப்புகளை மாற்றவும் செய்ய பல வழிகளை தருகின்றது',
	'uls-select-content-language' => 'மொழியைத் தேர்ந்தெடு',
);

/** Tagalog (Tagalog)
 * @author AnakngAraw
 * @author Sky Harbor
 */
$messages['tl'] = array(
	'UniversalLanguageSelector' => 'Unibersal na Pampili ng Wika',
	'uls-desc' => 'Nagbibigay sa tagagamit ng ilang mga paraan upang makapili ng isang wika at upang mabago ang mga katakdaan ng wika',
	'uls-select-content-language' => 'Piliin ang wika',
);

/** Urdu (اردو)
 * @author පසිඳු කාවින්ද
 */
$messages['ur'] = array(
	'UniversalLanguageSelector' => 'عالمگیر زبان منتخب',
	'uls-select-content-language' => 'زبان کا انتخاب کریں',
);

/** Vietnamese (Tiếng Việt)
 * @author Minh Nguyen
 */
$messages['vi'] = array(
	'UniversalLanguageSelector' => 'Bộ lựa chọn Ngôn ngữ Toàn thế giới',
	'uls-desc' => 'Trình bày giao diện để lựa chọn ngôn ngữ và điều chỉnh các tùy chọn ngôn ngữ',
	'uls-select-content-language' => 'Chọn ngôn ngữ',
);

/** Traditional Chinese (中文（繁體）‎)
 * @author Justincheng12345
 * @author Simon Shek
 */
$messages['zh-hant'] = array(
	'UniversalLanguageSelector' => '通用語言選擇器',
	'uls-desc' => '為用戶提供多種方法來選擇語言和調整語言設置',
	'uls-select-content-language' => '選擇語言',
);

==> MediaWikiLanguageExtensionBundle-2013.01.tar.bz2: extensions/UniversalLanguageSelector/UniversalLanguageSelector.i18n.php <==
<?php
/**
 * Internationalisation file for Universal Language Selector.
 *
 * Copyright (C) 2012 Alolita Sharma, Amir Aharoni, Arun Ganesh, Brandon Harris,
 * Niklas Laxström, Pau Giner, Santhosh Thottingal, Siebrand Mazeland and other
 * contributors. See CREDITS for a list.
 *
 * UniversalLanguageSelector is dual licensed GPLv2 or later and MIT. You don't
 * have to do anything special to choose one license or the other and you don't
 * have to notify anyone which license you are using. You are free to use
 * UniversalLanguageSelector in commercial projects as long as the copyright
 * header is left intact. See files GPL-LICENSE and MIT-LICENSE for details.
 *
 * @file
 * @ingroup Extensions
 * @licence GNU General Public Licence 2.0 or later
 * @licence MIT License
 */

$messages = array();

/**
 * English
 * @author santhosh
 */
$messages['en'] = array(
	'UniversalLanguageSelector' => 'Universal Language Selector',
	'uls-desc' => 'Gives the user several ways to select a language and to adjust language settings',
	'uls-select-content-language' => 'Select language',
);

/** Message documentation (Message documentation)
 * @author Shirayuki
 */
$messages['qqq'] = array(
	'UniversalLanguageSelector' => 'Extension name',
	'uls-desc' => 'Extension description',
	'uls-select-content-language' => 'Main heading in the language selector popup.
{{Identical|Select language}}',
);

/** Assamese (অসমীয়া)
 * @author Bishnu Saikia
 */
$messages['as'] = array(
	'UniversalLanguageSelector' => 'গোলকীয় ভাষা নিৰ্বাচক',
	'uls-select-content-language' => 'ভাষা নির্বাচন:',
);

/** Asturian (asturianu)
 * @author Xuacu
 */
$messages['ast'] = array(
	'UniversalLanguageSelector' => 'Selector universal de llingua',
	'uls-desc' => 'Ufre al usuariu delles maneres pa seleicionar una llingua y axustar la configuración de llingua',
	'uls-select-content-language' => 'Escueyi llingua',
);

/** Belarusian (Taraškievica orthography) (беларуская (тарашкевіца)‎)
 * @author Wizardist
 */
$messages['be-tarask'] = array(
	'UniversalLanguageSelector' => 'Унівэрсальны пераключальнік моваў',
	'uls-desc' => 'Дае карыстальніку некалькі спосабаў выбраць мову і зьмяніць моўныя налады',
	'uls-select-content-language' => 'Выбар мовы',
);

/** Breton (brezhoneg)
 * @author Y-M D
 */
$messages['br'] = array(
	'uls-select-content-language' => 'Dibab ar yezh',
);

/** Czech (česky)
 * @author Mormegil
 */
$messages['cs'] = array(
	'UniversalLanguageSelector' => 'Univerzální výběr jazyka',
	'uls-desc' => 'Nabízí uživateli několik způsobů volby jazyka a úpravy jazykových nastavení',
	'uls-select-content-language' => 'Vyberte jazyk',
);

/** Danish (dansk)
 * @author Christian List
 * @author Peter Alberti
 */
$messages['da'] = array(
	'UniversalLanguageSelector' => 'Universal sprogvælger',
	'uls-desc' => 'Giver brugeren forskellige måder at vælge et sprog, og at justere indstillingerne for sproget',
	'uls-select-content-language' => 'Vælg sprog',
);

/** German (Deutsch)
 * @author Kghbln
 * @author MF-Warburg
 * @author Metalhead64
 */
$messages['de'] = array(
	'UniversalLanguageSelector' => 'Universelle Sprachauswahl',
	'uls-desc' => 'Ermöglicht verschiedene Wege, eine Sprache auszuwählen und Spracheinstellungen anzupassen',
	'uls-select-content-language' => 'Sprache auswählen',
);

/** Lower Sorbian (dolnoserbski)
 * @author Michawiki
 */
$messages['dsb'] = array(
	'UniversalLanguageSelector' => 'Uniwersalny wuběrk rěcow',
	'uls-desc' => 'Dawa wužywarjeju wšake metody, aby rěc wubrał a rěcne nastajenja pśiměrił',
	'uls-select-content-language' => 'Rěc wubraś',
);

/** Esperanto (Esperanto)
 * @author Yekrats
 */
$messages['eo'] = array(
	'uls-select-content-language' => 'Elekti lingvon',
);

/** Spanish (español)
 * @author Armando-Martin
 */
$messages['es'] = array(
	'UniversalLanguageSelector' => 'Selector universal de idiomas',
	'uls-desc' => 'Ofrece al usuario varias formas para seleccionar un idioma y ajustar su configuración',
	'uls-select-content-language' => 'Seleccionar idioma',
);

/** Estonian (eesti)
 * @author Pikne
 */
$messages['et'] = array(
	'UniversalLanguageSelector' => 'Universaalne keelevalija',
	'uls-desc' => 'Võimaldab kasutajal mitmel viisil keelt valida ja keelesätteid kohandada.',
	'uls-select-content-language' => 'Keele valimine',
);

/** Basque (euskara)
 * @author An13sa
 */
$messages['eu'] = array(
	'uls-select-content-language' => 'Hizkuntza aukeratu',
);

/** Persian (فارسی)
 * @author Mjbmr
 */
$messages['fa'] = array(
	'uls-select-content-language' => 'انتخاب زبان',
);

/** Finnish (suomi)
 * @author Nike
 */
$messages['fi'] = array(
	'UniversalLanguageSelector' => 'Suuri kielenvalitsin',
	'uls-desc' => 'Tarjoaa useita tapoja valita kieli ja asettaa kieliasetukset',
	'uls-select-content-language' => 'Valitse kieli',
);

/** French (français)
 * @author Tititou36
 * @author Wyz
 */
$messages['fr'] = array(
	'UniversalLanguageSelector' => 'Sélecteur de Langue Universel',
	'uls-desc' => "Donne à l'utilisateur plusieurs manières de sélectionner une langue et d'ajuster les paramètres de langue",
	'uls-select-content-language' => 'Sélectionner la langue',
);

/** Galician (galego)
 * @author Toliño
 */
$messages['gl'] = array(
	'UniversalLanguageSelector' => 'Selector universal de linguas',
	'uls-desc' => 'Dá ao usuario varios xeitos de seleccionar unha lingua e de axustar as preferencias da mesma',
	'uls-select-content-language' => 'Seleccionar a lingua',
);

/** Hebrew (עברית)
 * @author Amire80
 */
$messages['he'] = array(
	'UniversalLanguageSelector' => 'בורר השפות העולמי',
	'uls-desc' => 'נותן למשתמשים מספר דרכים לבחור שפה ולכוונן את הגדרות השפה',
	'uls-select-content-language' => 'בחירת שפה',
);

/** Upper Sorbian (hornjoserbsce)
 * @author Michawiki
 */
$messages['hsb'] = array(
	'UniversalLanguageSelector' => 'Uniwersalny wuběr rěčow',
	'uls-desc' => 'Dawa wužiwarjej wšelake metody, zo by rěč wubrał a rěčne nastajenja přiměrił',
	'uls-select-content-language' => 'Rěč wubrać',
);

/** Italian (italiano)
 * @author Darth Kule
 */
$messages['it'] = array(
	'UniversalLanguageSelector' => 'Selettore universale della lingua',
	'uls-desc' => 'Fornisce agli utenti diversi modi di selezionare una lingua e sistemare le impostazioni della lingua',
	'uls-select-content-language' => 'Seleziona lingua',
);

/** Japanese (日本語)
 * @author Shirayuki
 */
$messages['ja'] = array(
	'UniversalLanguageSelector' => 'ユニバーサル言語選択',
	'uls-desc' => '言語を選択するため/言語設定を調整するための、いくつかの方法を利用者に提供する',
	'uls-select-content-language' => '言語を選択',
);

/** Georgian (ქართული)
 * @author გიორგიმელა
 */
$messages['ka'] = array(
	'UniversalLanguageSelector' => 'ენების უნივერსალური გადამრთველი',
	'uls-desc' => 'აძლევს მომხმარებელს ენის არჩევისა და კონფიგურაციის საშუალებას',
	'uls-select-content-language' => 'ენის არჩევა',
);

/** Korean (한국어)
 * @author 아라
 */
$messages['ko'] = array(
	'UniversalLanguageSelector' => '범용 언어 선택기',
	'uls-desc' => '사용자에게 언어를 선택하고 언어 설정을 바꾸는 몇 가지 방법을 제공',
	'uls-select-content-language' => '언어 선택',
);

/** Colognian (Ripoarisch)
 * @author Purodha
 */
$messages['ksh'] = array(
	'UniversalLanguageSelector' => 'Alljemein Schproochewahl',
	'uls-desc' => 'Jit dä Metmaachere ongerscheidlejje Müjjeleschkeite, en Schprooch ußzewähle un Enschtällonge für Schprooche ze maache.',
	'uls-select-content-language' => 'En Schprooch ußwähle',
);

/** Luxembourgish (Lëtzebuergesch)
 * @author Robby
 */
$messages['lb'] = array(
	'UniversalLanguageSelector' => 'Universell Auswiel vun der Sprooch',
	'uls-desc' => "Gëtt dem Benotzer verschidde Méiglechkeete fir eng Sprooch erauszesichen an d'Parameter vun der Sprooch festzeleeën",
	'uls-select-content-language' => 'Sprooch eraussichen',
);

/** Macedonian (македонски)
 * @author Bjankuloski06
 */
$messages['mk'] = array(
	'UniversalLanguageSelector' => 'Универзален избирач на јазици',
	'uls-desc' => 'Му дава на корисникот неколку начини за избор на јазик и прилагодување на јазичните поставки',
	'uls-select-content-language' => 'Одберете јазик',
);

/** Malayalam (മലയാളം)
 * @author Santhosh.thottingal
 */
$messages['ml'] = array(
	'UniversalLanguageSelector' => 'ആഗോള ഭാഷാസഹായി',
	'uls-desc' => 'ഭാഷ തിരഞ്ഞെടുക്കുന്നതിനും സജ്ജീകരിക്കുന്നതിനുമുള്ള സംവിധാനം',
	'uls-select-content-language' => 'ഭാഷ തിരഞ്ഞെടുക്കുക',
);

/** Malay (Bahasa Melayu)
 * @author Anakmalaysia
 */
$messages['ms'] = array(
	'UniversalLanguageSelector' => 'Pemilih Bahasa Sejagat',
	'uls-desc' => 'Membolehkan pengguna memilih bahasa dan mengubah tetapan bahasa dengan pelbagai cara',
	'uls-select-content-language' => 'Pilih bahasa',
);

/** Norwegian Bokmål (norsk (bokmål)‎)
 */
$messages['nb'] = array(
	'UniversalLanguageSelector' => 'Universal språkvelger',
	'uls-desc' => 'Gir brukeren flere måter å velge språk på og endre språkinnstillinger',
	'uls-select-content-language' => 'Velg språk',
);

/** Dutch (Nederlands)
 * @author Siebrand
 */
$messages['nl'] = array(
	'UniversalLanguageSelector' => 'Universele taalkiezer',
	'uls-desc' => 'Biedt gebruikers verschillende mogelijkheden om een taal te kiezen en bijbehorende instellingen aan te passen',
	'uls-select-content-language' => 'Taal selecteren',
);

/** Ossetic (Ирон)
 * @author Bouron
 */
$messages['os'] = array(
	'UniversalLanguageSelector' => 'Универсалон æвзагæвзарæн',
	'uls-desc' => 'Архайæгæн дæтты цалдæр фадат æвзаг равзарынæн æмæ йын уаг сæвæрынæн',
	'uls-select-content-language' => 'Æвзагæвзарæн',
);

/** Polish (polski)
 * @author BeginaFelicysym
 */
$messages['pl'] = array(
	'UniversalLanguageSelector' => 'Uniwersalny Selektor Języka',
	'uls-desc' => 'Daje użytkownikowi kilka sposobów, aby wybrać język i dostosować ustawienia języka',
	'uls-select-content-language' => 'Wybierz język',
);

/** Piedmontese (Piemontèis)
 * @author Dragonòt
 */
$messages['pms'] = array(
	'UniversalLanguageSelector' => 'Seletor Universal ëd Lenga',
	'uls-desc' => "A dà a l'utent vàire manere ëd selessioné na lenga e ëd sistemé j'ampostassion ëd lenga",
	'uls-select-content-language' => 'Serne la lenga',
);

/** Brazilian Portuguese (português do Brasil)
 * @author Jaideraf
 */
$messages['pt-br'] = array(
	'UniversalLanguageSelector' => 'Seletor universal de idiomas',
	'uls-desc' => 'Oferece ao usuário várias maneiras para selecionar um idioma e ajustar as configurações de idioma',
	'uls-select-content-language' => 'Selecionar idioma',
);

/** Romanian (română)
 * @author Minisarm
 */
$messages['ro'] = array(
	'UniversalLanguageSelector' => 'Selector universal de limbi',
	'uls-desc' => 'Oferă utilizatorului mai multe modalități de a selecta o limbă și de a modifica setările de limbă',
	'uls-select-content-language' => 'Selectare limbă',
);

/** Russian (русский)
 * @author Amire80
 */
$messages['ru'] = array(
	'UniversalLanguageSelector' => 'Универсальный переключатель языков',
	'uls-desc' => 'Даёт пользователю несколько способов выбрать язык и произвести установки языка',
	'uls-select-content-language' => 'Выбор языка',
);

/** Sinhala (සිංහල)
 * @author පසිඳු කාවින්ද
 */
$messages['si'] = array(
	'UniversalLanguageSelector' => 'විශ්ව භාෂා වරකය',
	'uls-select-content-language' => 'භාෂාව තෝරන්න',
);

/** Tamil (தமிழ்)
 * @author Logicwiki
 */
$messages['ta'] = array(
	'UniversalLanguageSelector' => 'உலகளாவிய மொழி தேர்வுக் கருவி',
	'uls-desc' => 'பயனருக்கு மொழியை மாற்றவும் மொழி அமைப்புகளை மாற்றவும் செய்ய பல வழிகளை தருகின்றது',
	'uls-select-content-language' => 'மொழியைத் தேர்ந்தெடு',
);

/** Tagalog (Tagalog)
 * @author AnakngAraw
 * @author Sky Harbor
 */
$messages['tl'] = array(
	'UniversalLanguageSelector' => 'Unibersal na Pampili ng Wika',
	'uls-desc' => 'Nagbibigay sa tagagamit ng ilang mga paraan upang makapili ng isang wika at upang mabago ang mga katakdaan ng wika',
	'uls-select-content-language' => 'Piliin ang wika',
);

/** Ukrainian (українська)
 * @author Steve.rusyn
 */
$messages['uk'] = array(
	'UniversalLanguageSelector' => 'Універсальний вибір мови',
	'uls-desc' => 'Надає користувачу декілька способів вибрати мову та налаштувати мовні параметри.',
	'uls-select-content-language' => 'Оберіть мову',
);

/** Urdu (اردو)
 * @author පසිඳු කාවින්ද
 */
$messages['ur'] = array(
	'UniversalLanguageSelector' => 'عالمگیر زبان منتخب',
	'uls-select-content-language' => 'زبان کا انتخاب کریں',
);

/** Vietnamese (Tiếng Việt)
 * @author Minh Nguyen
 */
$messages['vi'] = array(
	'UniversalLanguageSelector' => 'Bộ lựa chọn Ngôn ngữ Toàn thế giới',
	'uls-desc' => 'Trình bày giao diện để lựa chọn ngôn ngữ và điều chỉnh các tùy chọn ngôn ngữ',
	'uls-select-content-language' => 'Chọn ngôn ngữ',
);

/** Simplified Chinese (中文（简体）‎)
 * @author Shirayuki
 */
$messages['zh-hans'] = array(
	'UniversalLanguageSelector' => '通用语言选择器',
	'uls-desc' => '为用户提供多种方法来选择语言和调整语言设置',
	'uls-select-content-language' => '选择语言',
);

/** Traditional Chinese (中文（繁體）‎)
 * @author Justincheng12345
 * @author Simon Shek
 */
$messages['zh-hant'] = array(
	'UniversalLanguageSelector' => '通用語言選擇器',
	'uls-desc' => '為用戶提供多種方法來選擇語言和調整語言設置',
	'uls-select-content-language' => '選擇語言',
);
